'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var Transaction = require('./Transaction.cjs');

const generateSigner = context => createSignerFromKeypair(context, context.eddsa.generateKeypair());
const createSignerFromKeypair = (context, keypair) => ({
  publicKey: keypair.publicKey,
  secretKey: keypair.secretKey,
  async signMessage(message) {
    return context.eddsa.sign(message, keypair);
  },
  async signTransaction(transaction) {
    const message = transaction.serializedMessage;
    const signature = context.eddsa.sign(message, keypair);
    return Transaction.addTransactionSignature(transaction, signature, keypair.publicKey);
  },
  async signAllTransactions(transactions) {
    return Promise.all(transactions.map(transaction => this.signTransaction(transaction)));
  }
});

exports.createSignerFromKeypair = createSignerFromKeypair;
exports.generateSigner = generateSigner;
//# sourceMappingURL=KeyPair2.cjs.map
