import { generateSigner, createSignerFromKeypair } from './KeyPair2.mjs';

const signerIdentity = (signer, setPayer = true) => ({
  install(metaplex) {
    metaplex.identity = signer;
    if (setPayer) {
      metaplex.payer = signer;
    }
  }
});
const signerPayer = signer => ({
  install(metaplex) {
    metaplex.payer = signer;
  }
});
const generatedSignerIdentity = (setPayer = true) => ({
  install(metaplex) {
    const signer = generateSigner(metaplex);
    metaplex.use(signerIdentity(signer, setPayer));
  }
});
const generatedSignerPayer = () => ({
  install(metaplex) {
    const signer = generateSigner(metaplex);
    metaplex.use(signerPayer(signer));
  }
});
const keypairIdentity = (keypair, setPayer = true) => ({
  install(metaplex) {
    const signer = createSignerFromKeypair(metaplex, keypair);
    metaplex.use(signerIdentity(signer, setPayer));
  }
});
const keypairPayer = keypair => ({
  install(metaplex) {
    const signer = createSignerFromKeypair(metaplex, keypair);
    metaplex.use(signerPayer(signer));
  }
});

export { generatedSignerIdentity, generatedSignerPayer, keypairIdentity, keypairPayer, signerIdentity, signerPayer };
//# sourceMappingURL=SignerPlugins.mjs.map
